# -*- coding: utf-8 -*-

from email.header import Header
from email.mime.text import MIMEText
from email.utils import parseaddr, formataddr
from smtplib import SMTP
from tg import config
from tg import request

try:
    import turbomail
except ImportError:
    turbomail = None

try:
    from tgext.mailer import Message as message, Attachment
    from tgext.mailer import get_mailer
except ImportError:
    message = None

def get_reset_password_form():
    reset_password_config = config['_pluggable_resetpassword_config']
    reset_password_form = reset_password_config.get('reset_password_form_instance')
    if not reset_password_form:
        form_path = reset_password_config.get('reset_password_form', 'resetpassword.lib.forms.ResetPasswordForm')
        module, form_name = form_path.rsplit('.', 1)
        module = __import__(module, fromlist=form_name)
        form_class = getattr(module, form_name)
        reset_password_form = reset_password_config['reset_password_form_instance'] = form_class()

    return reset_password_form


def get_new_password_form():
    reset_password_config = config['_pluggable_resetpassword_config']

    new_password_form = reset_password_config.get('new_password_form_instance')
    if not new_password_form:
        form_path = reset_password_config.get('new_password_form', 'resetpassword.lib.forms.NewPasswordForm')
        module, form_name = form_path.rsplit('.', 1)
        module = __import__(module, fromlist=form_name)
        form_class = getattr(module, form_name)
        new_password_form = reset_password_config['new_password_form_instance'] = form_class()

    return new_password_form


def _plain_send_mail(sender, recipient, subject, body):
    header_charset = 'ISO-8859-1'
    for body_charset in 'US-ASCII', 'ISO-8859-1', 'UTF-8':
        try:
            body.encode(body_charset)
        except UnicodeError:
            pass
        else:
            break

    sender_name, sender_addr = parseaddr(sender)
    recipient_name, recipient_addr = parseaddr(recipient)

    sender_name = str(Header(unicode(sender_name), header_charset))
    recipient_name = str(Header(unicode(recipient_name), header_charset))

    sender_addr = sender_addr.encode('ascii')
    recipient_addr = recipient_addr.encode('ascii')

    msg = MIMEText(body.encode(body_charset), 'plain', body_charset)
    msg['From'] = formataddr((sender_name, sender_addr))
    msg['To'] = formataddr((recipient_name, recipient_addr))
    msg['Subject'] = Header(unicode(subject), header_charset)

    smtp = SMTP(config.get('resetpassword.smtp_host', 'localhost'), int(config.get('resetpassword.smtp_port', 0)))
    if config.get('resetpassword.smtp_login'):
        try:
            smtp.starttls()
        except:
            pass
        smtp.login(config.get('resetpassword.smtp_login'), config.get('resetpassword.smtp_passwd'))
    smtp.sendmail(sender, recipient, msg.as_string())
    smtp.quit()


def send_email(to_addr, sender, subject, body, rich=None):
    # Using turbomail if it exists, 'dumb' method otherwise
    if turbomail and config.get('mail.on'):
        msg = turbomail.Message(sender, to_addr, subject,  encoding='utf-8')
        msg.plain = body
        if rich:
            msg.rich = rich
        turbomail.enqueue(msg)
    # Using tgext.mailer pluggable if it exists, 'dumb' method otherwise
    elif message:
        mailer = get_mailer(request)
        message_to_send = message(
            subject=subject,
            sender=sender,
            recipients=[to_addr],
            body=body,
            html=rich or None
        )
        mailer.send(message_to_send)
    else:
        _plain_send_mail(sender, to_addr, subject, body)



# coding=utf-8

from __future__ import unicode_literals
from formencode.validators import FieldsMatch
from resetpassword.lib.validators import RegisteredUserValidator
from tw2.core import Validator

from tw2.forms import TableForm, HiddenField, PasswordField, SubmitButton, TextField
from tg.i18n import lazy_ugettext as l_


class NewPasswordForm(TableForm):
    data = HiddenField()
    password = PasswordField(label=l_('New password'), validator=Validator(required=True))
    password_confirm = PasswordField(label=l_('Confirm new password'), validator=Validator(required=True))
    validator = FieldsMatch('password', 'password_confirm')
    submit = SubmitButton(value=l_('Save new password'))


class ResetPasswordForm(TableForm):
    email_address = TextField(label=l_('Email address'), validator=RegisteredUserValidator(required=True))
    submit = SubmitButton(value=l_('Send Request'))



# -*- coding: utf-8 -*-
"""The tgapp-resetpassword package"""

import tg
from tg.configuration import milestones


def plugme(app_config, options):
    app_config['_pluggable_resetpassword_config'] = options

    from resetpassword import model
    milestones.config_ready.register(model.configure_models)
    milestones.environment_loaded.register(model.configure_provider)
    return dict(appid='resetpassword', global_helpers=False)


# -*- coding: utf-8 -*-
import sys, os

try:
    from setuptools import setup, find_packages
except ImportError:
    from ez_setup import use_setuptools
    use_setuptools()
    from setuptools import setup, find_packages

install_requires=[
    "TurboGears2 >= 2.3.1",
    "tgext.pluggable",
    "tw2.core",
    "tw2.forms >= 2.2.0.3",
    "sprox >= 0.9.1",
    'itsdangerous'
]

here = os.path.abspath(os.path.dirname(__file__))
try:
    README = open(os.path.join(here, 'README.rst')).read()
except IOError:
    README = ''

setup(
    name='tgapp-resetpassword',
    version='0.1.6',
    description='Pluggable application for TurboGears2 that permits to change user password or reset it when lost, with sqla and ming compatibility',
    long_description=README,
    author='Simone Gasbarroni',
    author_email='simone.gasbarroni@gmail.com',
    url='https://github.com/gasbasd/tgapp-resetpassword',
    license='MIT',
    keywords='turbogears2.application',
    packages=find_packages(exclude=['ez_setup']),
    install_requires=install_requires,
    include_package_data=True,
    package_data={'resetpassword': [
        'i18n/*/LC_MESSAGES/*.mo',
        'templates/*/*',
        'public/*/*'
    ]},
    message_extractors={'resetpassword': [
            ('**.py', 'python', None),
            ('templates/**.html', 'genshi', None),
            ('public/**', 'ignore', None)
    ]},
    entry_points="""
    """,
    zip_safe=False
)
